#!/bin/bash

set -e

gzip -d -k -c ../00_edfblocktypes/multi5.edf.gz > multi5+pitfalls.edf

#H5    89 48 44 46 0d 0a 1a 0a  .HDF..    (Hierarchical Data Format (version 5) data)
#EDF3  0d 0a 7b 0d 0a 45 44 46  ..{..EDF  (EDF V2.xx)
#EDF2  0a 7b 0d 0a 45 44 46     .{..EDF   (EDF V2.xx)
#EDF1  7b 0d 0a 45 44 46        {..EDF    (EDF >=V2.4 fit2d friendly, without starting newline)
#EDF0  7b 0a                    {.        (EDF V1.xx "standard")
#EDFU  0a 7b 0a                 .{.       (EDF unknown source, V1.xx)
#GZIP  1F 8B                              (gzip compressed file)
#Z     78 9C                              (Zlib compressed file)
#BSL                                      text file with at least 4 lines,
#                                         i.e >= 3 newlines in the first 320 characters
#                                         (3 0x0d 0x0a, 3 0x0d or 3 0x0a) cr/lf, cr or lf)
#file = multi5+pitfalls.edf
#chain = Image.Psd
#  block = 1
#   HeaderBlockPos = 0 (0), Length = 8192 (0x2000)
#   BinaryBlockPos = 8192 (0x2000), Length = 2560 (0xa00)
#chain = Image.Psd
#  block = 2
#   HeaderBlockPos = 10752 (0x2a00), Length = 8192 (0x2000)
#   BinaryBlockPos = 18944 (0x4a00), Length = 2560 (0xa00)
#chain = Image.Psd
#  block = 3
#   HeaderBlockPos = 21504 (0x5400), Length = 8192 (0x2000)
#   BinaryBlockPos = 29696 (0x7400), Length = 2560 (0xa00)
#chain = Image.Psd
#  block = 4
#   HeaderBlockPos = 32256 (0x7e00), Length = 8192 (0x2000)
#   BinaryBlockPos = 40448 (0x9e00), Length = 2560 (0xa00)
#chain = Image.Psd
#  block = 5
#   HeaderBlockPos = 43008 (0xa800), Length = 8192 (0x2000)
#   BinaryBlockPos = 51200 (0xc800), Length = 2560 (0xa00)


dd bs=1 count=8192 if=multi5+pitfalls.edf of=header1
dd bs=1 count=2560 skip=8192 if=multi5+pitfalls.edf of=blob1

dd bs=1 count=8192 skip=10752 if=multi5+pitfalls.edf of=header2
dd bs=1 count=2560 skip=18944 if=multi5+pitfalls.edf of=blob2

dd bs=1 count=8192 skip=21504 if=multi5+pitfalls.edf of=header3
dd bs=1 count=2560 skip=29696 if=multi5+pitfalls.edf of=blob3

dd bs=1 count=8192 skip=32256 if=multi5+pitfalls.edf of=header4
dd bs=1 count=2560 skip=40448 if=multi5+pitfalls.edf of=blob4

dd bs=1 count=8192 skip=43008 if=multi5+pitfalls.edf of=header5
dd bs=1 count=2560 skip=51200 if=multi5+pitfalls.edf of=blob5


# for test
cat header1 blob1 header2 blob2 header3 blob3 header4 blob4 header5 blob5 > multi5+pitfalls_edf1.edf
diff multi5+pitfalls.edf multi5+pitfalls_edf1.edf

rm -f multi5+pitfalls.edf

#The following section have been edited manually and then 
#concatenated to an edf-file for checking correct parsing of the file
#headerblob: a binary section with many header start and end characters
#headerendinheader: the first file header that contains a header end character

#multi5+pitfalls_edf1.edf                      # identical to original file without modifications
#multi5+headerblob_edf1.edf                    # for checking that binary blobs are not used as header
                                               # all binary blobs contain header start/end characters ({})
#multi5+headerblob+headerendinheader_edf1.edf  # for testing the behaviour if a header value contains a header end pattern
                                               # the Title of the first header contains an header end character ({\r\n)

# The following files are copies of the above files, but without EDF_* keys.
# They must be read as edf0 files by parsing the header.
#multi5+pitfalls_edf0.edf                      # multi5+pitfalls_edf1.edf without EDF_* keys
#multi5+headerblob_edf0.edf                    # multi5+headerblob_edf1.edf without EDF_* keys
#multi5+headerblob+headerendinheader_edf0.edf  # multi5+headerblob+headerendinheader_edf1.edf without EDF_* keys
                                               # Without the EDF_HeaderSize value reading this file will probably fail

